<?php
/**
 * NLSClientScript v 4.0 RC
 * 
 * CClientScript extension for preventing multiple loading of javascript files.
 * Important! This extension does not prevent to load the same script content from different paths. 
 * So eg. if you published the same js file into different asset directories, this extension won't prevent to load both.
 * 
 * 
 * 
 * Usage: simply set the class for the clientScript component in /protected/config/main.php, like
 *  ...
 *   'components'=>array(
 *     ...
 *     'clientScript' => array('class'=>'your.path.to.NLSClientScript')
 *     ...
 *   )
 *  ...
 * 
 * The extension is based on the great idea of Eirik Hoem, see
 * http://www.eirikhoem.net/blog/2011/08/29/yii-framework-preventing-duplicate-jscss-includes-for-ajax-requests/
 * 
 */
class NLSClientScript extends CClientScript {

/**
 * Applying global ajax post-filtering
 * original source: http://www.eirikhoem.net/blog/2011/08/29/yii-framework-preventing-duplicate-jscss-includes-for-ajax-requests/
*/
	public $processedPattern = '';
	public $ignoredPattern = '';
	
	public function getScriptFiles() {
		return $this->scriptFiles;
	}
	
	public function renderHead(&$output) {

		$this->_putnlscode();

		parent::renderHead($output);
	}

	protected function _putnlscode() {

		if (Yii::app()->request->isAjaxRequest)
			return;

		//we need jquery
		$this->registerCoreScript('jquery');

		//Minified code
		$this->registerScript('fixDuplicateResources', '$.ajaxSetup({global:!0,dataFilter:function(h,i){if(i&&"html"!=i&&"text"!=i)return h;' . ($this->processedPattern ? 'if (!this.url.match(' . $this->processedPattern . '))return data;' : '') . '
' . ($this->ignoredPattern ? 'if (this.url.match(' . $this->ignoredPattern . '))return data;' : '') . 'var c,d,j,a,e,b,g,k;if(!$._nlsc){$._nlsc={resMap:{},selector:"script[src],link[href]",slRg:/(<script.+?src=.+?>)|(<link.+?href=.+?>)/ig,urlGarbageRg:/([?&]+$)|(_=\d+)/g,holder:$("<div>"),urlConverter:navigator.appVersion.match(/MSIE ([6-7]\.)/)?$(\'<a href="#"></a>\')[0]:null,isIe:navigator.appVersion.match(/MSIE/)};b=$._nlsc.urlConverter;g=$._nlsc.urlGarbageRg;for(d=0,j=$(document).find($._nlsc.selector);d<j.length;d++)if(c= j[d],a=c.src?c.src:c.href)b&&(b.href=a,a=b.href),$._nlsc.resMap[a.replace(g,"")]=1}e=$._nlsc.holder[0];b=$._nlsc.urlConverter;g=$._nlsc.urlGarbageRg;k=$._nlsc.isIe;return h=h.replace($._nlsc.slRg,function(f,c,d){k&&c&&(f=f.replace(/defer[^\s>]*/ig," "));if(!(e.innerHTML="<wbr/>"+f)||!e.lastChild)return f;a=c?e.lastChild.src:d?e.lastChild.href:"";b&&(b.href=a,a=b.href);if(a=a.replace(g,"")){if($._nlsc.resMap[a])return"";$._nlsc.resMap[a]=1}return f})}});', CClientScript::POS_HEAD);


//Source code:
/*

$this->registerScript('fixDuplicateResources', '

$.ajaxSetup({
	global: true,
	dataFilter: function(data,type) {

		//shortcut: only "text" and "html" dataType should be filtered
		if (type && type != "html" && type != "text")
			return data;
		
' . ($this->processedPattern ? 'if (!this.url.match(' . $this->processedPattern . '))return data;' : '') . '
' . ($this->ignoredPattern ? 'if (this.url.match(' . $this->ignoredPattern . '))return data;' : '') . '

		var tmp,i,res,ind,holder,uc,resMap,gbRg,isIe;

		//things to do only first time
		if (!$._nlsc) {

			$._nlsc = {
				resMap : {},
				selector : "script[src],link[href]", 
				slRg : /(<script.+?src=.+?>)|(<link.+?href=.+?>)/ig,
				urlGarbageRg : /([?&]+$)|(_=\d+)/g,
				holder : $("<div>"),
				urlConverter : navigator.appVersion.match(/MSIE ([6-7]\.)/) ? $("<a href=\"#\"></a>")[0] : null,
				isIe : navigator.appVersion.match(/MSIE/)
			};
			
			uc = $._nlsc.urlConverter;
			gbRg = $._nlsc.urlGarbageRg;

			//fetching scripts from the DOM
			for(i=0,res=$(document).find($._nlsc.selector); i<res.length; i++) {
				tmp = res[i];
				ind = (tmp.src ? tmp.src : tmp.href);
				if (!ind) continue;
				
				//forcing absolute url
				if (uc) {
					uc.href = ind;ind = uc.href;			
				}

				$._nlsc.resMap[ind.replace(gbRg,"")] = 1;
			}

		}//if
		
		holder = $._nlsc.holder[0];
		uc = $._nlsc.urlConverter;
		gbRg = $._nlsc.urlGarbageRg;
		isIe = $._nlsc.isIe;

		data = data.replace($._nlsc.slRg, function(full_match, script, link, offset, data) {
			if (isIe && script)
				full_match = full_match.replace(/defer[^\s>]*X/ig," ");//remove X...

			if (!(holder.innerHTML = ("<wbr/>"+full_match)) || !holder.lastChild)
				return full_match;

			ind = script ? holder.lastChild.src : (link ? holder.lastChild.href : "");

			if (uc) {
				uc.href = ind;ind = uc.href;			
			}

			if (ind = ind.replace(gbRg,"")) {
				if ($._nlsc.resMap[ind])
					return "";
				$._nlsc.resMap[ind] = 1;
			}
			return full_match;
		});

		return data;
	}
});

',	CClientScript::POS_HEAD);


*/
	}

}
